/*
 * Copyright (C) 2006-2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

using System;
using System.Collections;
using System.Net;

using NUnit.Framework;

using DCSharp.Backend.Managers;
using DCSharp.Backend.Objects;

namespace DCSharp.Backend.Managers.Test
{
	[TestFixture()]
	public class DownloadManagerTest
	{
		private DownloadManager manager;
		private DownloadFileInfo download;
		
		[SetUp]
		public void SetUp()
		{
			HubManager hubManager = new HubManager();
			ConnectionManager connectionManager = new ConnectionManager(hubManager);
			
			manager = new DownloadManager(connectionManager, new Listener(hubManager));
			download = new DownloadFileInfo("download", 0, null, null);
		}
		
		[Test]
		public void Add()
		{
			manager.Add(download);
			manager.Add(download);
			
			Assert.IsTrue(manager.Count == 1);
			Assert.IsTrue(manager.Contains(download));
		}
		
		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void AddNull()
		{
			manager.Add(null);
		}
		
		[Test]
		public void Remove()
		{
			Add();
			
			manager.Remove(download);
			manager.Remove(download);
			
			Assert.IsTrue(manager.Count == 0);
			Assert.IsFalse(manager.Contains(download));
		}
		
		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void RemoveNull()
		{
			manager.Remove(null);
		}
		
		[Test]
		public void Contains()
		{
			Assert.IsFalse(manager.Contains(null));
		}
	}
}
