/*
 * Copyright (C) 2006-2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

using System;
using System.Collections;

using NUnit.Framework;

using DCSharp.Backend.Managers;
using DCSharp.Backend.Objects;

namespace DCSharp.Backend.Managers.Test
{
	[TestFixture()]
	public class UserManagerTest
	{
		private UserManager manager;
		private LocalIdentity identity;
		
		[SetUp]
		public void SetUp()
		{
			Uid pid = Uid.Generate();
			identity = new LocalIdentity(pid, "Nick");
			
			manager = new UserManager();
		}
		
		[Test]
		public void Add()
		{
			manager.Add(identity);
			manager.Add(identity);
			
			Assert.IsTrue(manager.Count == 1);
			Assert.IsTrue(manager.Contains(identity));
			Assert.AreSame(identity, manager[identity.User]);
		}
		
		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void AddNull()
		{
			manager.Add(null);
		}
		
		[Test]
		public void Remove()
		{
			Add();
			
			manager.Remove(identity);
			manager.Remove(identity);
			
			Assert.IsTrue(manager.Count == 0);
			Assert.IsFalse(manager.Contains(identity));
			Assert.IsNull(manager[identity.User]);
		}
		
		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void RemoveNull()
		{
			manager.Remove(null);
		}
		
		[Test]
		public void Contains()
		{
			Assert.IsFalse(manager.Contains(null));
		}
		
		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void Item()
		{
			Assert.IsNull(manager[User.Create(Uid.Generate(), "Unknown")]);
			Assert.IsNull(manager[null]);
		}
	}
}
